core/navigation/providers/navigation_providers library

Classes

GoRouterProvider
Provider for the GoRouter instance with auth-based routing Keep alive ensures the router is never disposed during app lifetime

Properties

goRouterProvider GoRouterProvider
Provider for the GoRouter instance with auth-based routing Keep alive ensures the router is never disposed during app lifetime
final

Functions

goRouter(Ref ref) → GoRouter
Provider for the GoRouter instance with auth-based routing Keep alive ensures the router is never disposed during app lifetime