core/updates/app_update_gateway library

Classes

AppUpdateGateway
Testable boundary around Play in-app updates and browser reload.
PluginAppUpdateGateway
Plugin-backed update gateway used by production apps.

Enums

ClientUpdatePlatform
Update mechanism available to this build.
NativeUpdateAttempt
Result of asking the operating system to begin an update.
NativeUpdateAvailability
Native update state normalized across the platform plugin and app shell.