AppUpdateGateway class abstract interface

Testable boundary around Play in-app updates and browser reload.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
platform ClientUpdatePlatform
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUpdate() Future<NativeUpdateAvailability>
completeFlexibleUpdate() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performImmediateUpdate() Future<NativeUpdateAttempt>
reloadWeb() Future<void>
startFlexibleUpdate() Future<NativeUpdateAttempt>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited