PluginAppUpdateGateway class

Plugin-backed update gateway used by production apps.

Implemented types

Constructors

PluginAppUpdateGateway()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
platform ClientUpdatePlatform
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUpdate() Future<NativeUpdateAvailability>
override
completeFlexibleUpdate() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performImmediateUpdate() Future<NativeUpdateAttempt>
override
reloadWeb() Future<void>
override
startFlexibleUpdate() Future<NativeUpdateAttempt>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited