reloadBrowser function
void
reloadBrowser()
Reloads the current browser document from its existing URL.
Implementation
void reloadBrowser() => web.window.location.reload();
Reloads the current browser document from its existing URL.
void reloadBrowser() => web.window.location.reload();