checkForUpdate method
Checks for an available Android update without interrupting active play.
Implementation
Future<void> checkForUpdate() => _backgroundCheck ??= _checkForUpdate()
.whenComplete(() => _backgroundCheck = null);
Checks for an available Android update without interrupting active play.
Future<void> checkForUpdate() => _backgroundCheck ??= _checkForUpdate()
.whenComplete(() => _backgroundCheck = null);