core/utils/deep_links library

Functions

Returns a shareable invite link for the given join code, or null if appHost is not configured.
Returns a shareable link to replay the finished game with gameId, or null if appHost is not configured.
legalPageUrl(String path, {required String? appHost}) Uri?
Returns a URL for the given legal path on the game's own host, or null if appHost is not configured.