features/game/providers/replay_controller library
Classes
- ReplayCursor
- The current position within a game's replay, as an index into replayFramesProvider.
- ReplayCursorFamily
- The current position within a game's replay, as an index into replayFramesProvider.
- ReplayCursorProvider
- The current position within a game's replay, as an index into replayFramesProvider.
- ReplayFrameAtFamily
-
The
GameFramefor a single replay frame index. - ReplayFrameAtProvider
-
The
GameFramefor a single replay frame index. - ReplayFramesFamily
- The full ordered frame history of a finished game.
- ReplayFramesProvider
- The full ordered frame history of a finished game.
- ReplayTransitionAtFamily
-
The step into the frame at
index, or null on the first frame. - ReplayTransitionAtProvider
-
The step into the frame at
index, or null on the first frame.
Properties
- replayCursorProvider → ReplayCursorFamily
-
The current position within a game's replay, as an index into
replayFramesProvider.
final
- replayFrameAtProvider → ReplayFrameAtFamily
-
The
GameFramefor a single replay frame index.final - replayFramesProvider → ReplayFramesFamily
-
The full ordered frame history of a finished game.
final
- replayTransitionAtProvider → ReplayTransitionAtFamily
-
The step into the frame at
index, or null on the first frame.final
Functions
-
replayFrameAt(
Ref ref, {required String gameId, required int index}) → GameFrame? -
The
GameFramefor a single replay frame index. -
replayFrames(
Ref ref, {required String gameId}) → Future< List< Frame> > - The full ordered frame history of a finished game.
-
replayTransitionAt(
Ref ref, {required String gameId, required int index}) → GameTransition? -
The step into the frame at
index, or null on the first frame.